
==============
Numina modules
==============

.. toctree::

   array
   core/index
   dal
   datamodel
   drps
   exceptions
   frame
   instrument
   logger
   modeling
   processing
   qa
   store
   treedict
   types
   user
   util
   visualization
   xdgdirs
   
